@@ -108,7 +108,7 @@ function yetus_relative_dir
 {
   declare dir=$1
   declare path=$2
-  declare p=${path#${dir}}
+  declare p=${path#"${dir}"}
 
   if [[ ${#p} -eq ${#path} ]]; then
     echo "${p}"
@@ -143,7 +143,7 @@ function yetus_add_option
   declare option=$1
   declare text=$2
 
-  YETUS_OPTION_USAGE[${YETUS_OPTION_USAGE_COUNTER}]="${option}@${text}"
+  YETUS_OPTION_USAGE[YETUS_OPTION_USAGE_COUNTER]="${option}@${text}"
   ((YETUS_OPTION_USAGE_COUNTER=YETUS_OPTION_USAGE_COUNTER+1))
 }
 
@@ -191,7 +191,7 @@ function yetus_generic_columnprinter
   fi
 
   while read -r line; do
-    tmpa[${counter}]=${line}
+    tmpa[counter]=${line}
     ((counter=counter+1))
     option="${line%%@*}"
     if [[ ${#option} -gt ${maxoptsize} ]]; then
@@ -280,11 +280,11 @@ function yetus_file_to_array
     # work due to the variable only being present in
     # the subshell.  So MUST force the grep into the
     # subshell...
-    mapfile -t a < <("${GREP:-grep}" -v -e '^#' -e '^$' "${filename}" )
+    mapfile -t a < <("${GREP:-grep}" -v -E -e '^#' -e '^[[:space:]]*$' "${filename}" )
   else
     while read -r line; do
       a+=("${line}")
-    done < <("${GREP:-grep}" -v -e '^#' -e '^$' "${filename}")
+    done < <("${GREP:-grep}" -v -E -e '^#' -e '^[[:space:]]*$' "${filename}")
   fi
   eval "${var}=(\"\${a[@]}\")"
   return 0
@@ -513,3 +513,110 @@ function yetus_get_ctime
     date +"%s"
   fi
 }
+
+## @description  Set a trap passing the first param as the signal
+## @audience     public
+## @stability    stable
+## @param        function
+## @param        signal
+## @param        [signal]
+function yetus_set_trap_handler
+{
+  local func="$1" ; shift
+  for signal ; do
+    # shellcheck disable=SC2064
+    trap "${func} ${signal}" "${signal}"
+  done
+}
+
+## @description  Determine if running in a container
+## @audience     public
+## @stability    evolving
+## @replaceable  no
+function yetus_is_container
+{
+  declare mounts
+  declare cgroups
+
+  # shortcut logic
+  if [[ -n "${YETUS_CONTAINER_STATE}" ]]; then
+    if [[ "${YETUS_CONTAINER_STATE}" == "true" ]]; then
+      return 0
+    fi
+    return 1
+  fi
+
+  # NOTE: there is no official 'is this a container?' API
+  # as of this writing that works 100%.  In fact, there are
+  # no APIs at all that could be considered stable. So this
+  # function basically performs some guesswork based upon
+  # some common things.
+
+  # Docker creates this file but it isn't guaranteed by
+  # them.
+  if [[ -f /.dockerenv ]]; then
+    YETUS_CONTAINER_STATE=true
+    return 0
+  fi
+
+  # LXC and others sets the container env var to be
+  # something.
+  if [[ -n "${container}" ]]; then
+    YETUS_CONTAINER_STATE=true
+    return 0
+  fi
+
+  #
+  # docker and lxc will tend to mount things onto /docker or /containers
+  # (depending upon OS, version involved, etc)
+  #
+  if [[ -d /proc/self/mountinfo ]]; then
+    mounts=$(awk '$4 ~ /^\/docker/ {print $1}' /proc/self/mountinfo)
+    if [[ -n "${mounts}" ]]; then
+      YETUS_CONTAINER_STATE=true
+      return 0
+    fi
+  fi
+
+  if [[ -d /proc/self/mountinfo ]]; then
+    mounts=$(awk '$4 ~ /^\/container/ {print $1}' /proc/self/mountinfo)
+    if [[ -n "${mounts}" ]]; then
+      YETUS_CONTAINER_STATE=true
+      return 0
+    fi
+  fi
+
+  #
+  # docker and lxc will tend to create docker or lxc cgroups,
+  # depending upon the OS configuration
+  #
+  if [[ -d /proc/self/cgroup ]]; then
+    cgroups=$(awk '$4 ~ /docker/ {print $1}'  /proc/self/cgroup)
+    if [[ -n "${cgroups}" ]]; then
+      YETUS_CONTAINER_STATE=true
+      return 0
+    fi
+  fi
+
+  if [[ -d /proc/self/cgroup ]]; then
+    cgroups=$(awk '$4 ~ /lxc/ {print $1}'  /proc/self/cgroup )
+    if [[ -n "${cgroups}" ]]; then
+      YETUS_CONTAINER_STATE=true
+      return 0
+    fi
+  fi
+
+  YETUS_CONTAINER_STATE=false
+  return 1
+}
+
+## @description  Given a string, trim extra surrounding whitespace
+## @audience     public
+## @stability    stable
+## @replaceable  no
+function yetus_trim {
+    declare var="$*"
+    var="${var#"${var%%[![:space:]]*}"}"
+    var="${var%"${var##*[![:space:]]}"}"
+    printf '%s' "$var"
+}
