@@ -23,6 +23,7 @@ DOCKER_DESTRUCTIVE=true
 DOCKERFILE_DEFAULT="${BINDIR}/test-patch-docker/Dockerfile"
 DOCKERSUPPORT=false
 DOCKER_ENABLE_PRIVILEGED=false
+DOCKER_BUILD_OUTPUT=${DOCKER_BUILDKIT_SETTING:-true}
 DOCKER_CLEANUP_CMD=false
 DOCKER_MEMORY="4g"
 DOCKER_PLATFORM=""
@@ -31,6 +32,7 @@ DOCKER_IN_DOCKER=false
 DOCKER_SOCKET="/var/run/docker.sock"
 DOCKER_SOCKET_GID=-1
 DOCKER_WORK_DIR="/precommit"
+DOCKER_ASF_BUILT_REPO="ghcr.io/apache/yetus"
 
 declare -a DOCKER_EXTRAARGS
 declare -a DOCKER_EXTRABUILDARGS
@@ -67,6 +69,7 @@ function docker_usage
   yetus_add_option "--docker-buildkit=<bool>" "Set the Docker BuildKit availability (default: ${DOCKER_BUILDKIT_SETTING})'"
   if [[ "${DOCKER_CLEANUP_CMD}" == false ]]; then
     yetus_add_option "--docker-bash-debug=<bool>" "Enable bash -x mode running in a container (default: ${YETUS_DOCKER_BASH_DEBUG})"
+    yetus_add_option "--docker-build-output=<bool>" "Send docker build output to the screen (default: '${DOCKER_BUILD_OUTPUT}')"
     yetus_add_option "--docker-cache-from=<image>" "Comma delimited images to use as a cache when building"
     yetus_add_option "--dockerfile=<file>" "Dockerfile fragment to use as the base (default: '${DOCKERFILE_DEFAULT}')"
     yetus_add_option "--dockerind=<bool>" "Enable Docker-in-Docker by mounting the Docker socket in the container (default: '${DOCKER_IN_DOCKER}')"
@@ -106,6 +109,10 @@ function docker_parse_args
         delete_parameter "${i}"
         DOCKER_BUILDKIT_SETTING=${i#*=}
       ;;
+      --docker-build-output=*)
+        delete_parameter "${i}"
+        DOCKER_BUILD_OUTPUT=${i#*=}
+      ;;
       --docker-cache-from=*)
         delete_parameter "${i}"
         DOCKER_CACHE_FROM=${i#*=}
@@ -255,11 +262,11 @@ function docker_fileverify
         dockplat=('--platform' "${DOCKER_PLATFORM}")
       fi
 
-      echo "No --dockerfile or --docker-tag provided. Attempting to pull apache/yetus:${VERSION}."
+      echo "No --dockerfile or --docker-tag provided. Attempting to pull ${DOCKER_ASF_BUILT_REPO}:${VERSION}."
 
-      if dockercmd pull "${dockplat[@]}" "apache/yetus:${VERSION}"; then
+      if dockercmd pull "${dockplat[@]}" "${DOCKER_ASF_BUILT_REPO}:${VERSION}"; then
         echo "Pull succeeded; will build with pulled image."
-        DOCKER_TAG="apache/yetus:${VERSION}"
+        DOCKER_TAG="${DOCKER_ASF_BUILT_REPO}:${VERSION}"
       else
         echo "Pull failed; will build with built-in Dockerfile."
         DOCKERFILE=${DOCKERFILE_DEFAULT}
@@ -539,6 +546,9 @@ function docker_image_maintenance
   echo "Other images:"
   #shellcheck disable=SC2046
   docker_image_maintenance_helper $(docker_get_sentinel_images)
+
+  echo "docker buildx cache"
+  dockercmd buildx prune --force --filter=until="${DOCKER_IMAGE_PURGE}s"
 }
 
 
@@ -707,6 +717,7 @@ function docker_run_image
       fi
     fi
 
+    # shellcheck disable=SC2030
     (
       if [[ -z "${lines}" ]]; then
         cat "${DOCKERFILE}"
@@ -715,6 +726,7 @@ function docker_run_image
       fi
     ) > "${buildfile}"
 
+    # shellcheck disable=SC2031
     if [[ ${lines} -gt 0 ]]; then
       if [[ "${DOCKER_VERSION[0]}" -lt 1 ]] || \
        [[ "${DOCKER_VERSION[0]}" -lt 2 && "${DOCKER_VERSION[1]}" -lt 38 ]]; then
@@ -732,20 +744,37 @@ function docker_run_image
       cachefrom=("--cache-from=yetus/${PROJECT_NAME}:${gitfilerev},${DOCKER_CACHE_FROM}")
     fi
 
-    if ! dockercmd build \
-          "${dockplat[@]}" \
-          "${cachefrom[@]}" \
-          --label org.apache.yetus=\"\" \
-          --label org.apache.yetus.testpatch.project="${PROJECT_NAME}" \
-          --tag "${baseimagename}" \
-          "${DOCKER_EXTRABUILDARGS[@]}" \
-          -f "${buildfile}" \
-          "${dockerdir}"; then
+    dockerbuild=(build "${dockplat[@]}" "${cachefrom[@]}")
+    dockerbuild+=(--label org.apache.yetus=\"\")
+    dockerbuild+=(--label org.apache.yetus.testpatch.project="${PROJECT_NAME}")
+    dockerbuild+=(--tag "${baseimagename}")
+    dockerbuild+=("${DOCKER_EXTRABUILDARGS[@]}")
+    dockerbuild+=(-f "${buildfile}")
+    dockerbuild+=("${dockerdir}")
+
+    if [[ "${DOCKER_BUILD_OUTPUT}" == 'true' ]]; then
+      echo "Starting docker build..."
+      dockercmd "${dockerbuild[@]}"
+      dockerlogfile=""
+    else
+      echo "Starting docker build..."
+      dockercmd "${dockerbuild[@]}" > "${PATCH_DIR}/docker-build.log" 2>&1
+      dockerlogfile="${PATCH_DIR}/docker-build.log"
+    fi
+
+    # shellcheck disable=SC2181
+    if [[ $? != 0 ]]; then
       popd >/dev/null || return 1
       yetus_error "ERROR: Docker failed to build ${baseimagename}."
-      add_vote_table_v2 -1 docker "" "Docker failed to build ${baseimagename}."
+      gitdockerfile=$(yetus_relative_dir "${BASEDIR}" "${DOCKERFILE}")
+      echo "${gitdockerfile}:1:Failed to build Dockerfile" > "${PATCH_DIR}/dockerline.log"
+      bugsystem_linecomments_queue docker "${PATCH_DIR}/dockerline.log"
+      rm "${PATCH_DIR}/dockerline.log"
+      add_vote_table_v2 -1 docker "${dockerlogfile}" "Docker failed to build ${baseimagename}."
       bugsystem_finalreport 1
       cleanup_and_exit 1
+    elif [[ -n "${dockerlogfile}" ]]; then
+      add_vote_table_v2 +1 docker "${dockerlogfile}" "Docker build log ${baseimagename}."
     fi
     popd >/dev/null || return 1
   fi
@@ -840,7 +869,7 @@ function docker_run_image
 
   DOCKER_EXTRAARGS+=(--name "${containername}")
 
-  trap 'docker_signal_handler' SIGTERM SIGINT SIGHUP
+  yetus_set_trap_handler docker_signal_handler HUP INT QUIT TERM
 
   if [[ ${PATCH_DIR} =~ ^/ ]]; then
     dockercmd run --rm=true -i \
@@ -872,11 +901,12 @@ function docker_run_image
 ## @replaceable  no
 function docker_signal_handler
 {
+  declare signal=$1
   declare cid
 
   cid=$(cat "${PATCH_DIR}/cidfile.txt")
 
-  yetus_error "ERROR: Caught signal. Killing docker container:"
+  yetus_error "ERROR: Caught signal ${signal}. Killing docker container:"
   echo "ERROR: Caught signal. Killing docker container: ${cid}" > "${PATCH_DIR}/signal.log"
   dockercmd kill "${cid}" | tee -a "${PATCH_DIR}/signal.log"
   rm "${PATCH_DIR}/cidfile.txt"
